@@ -14,7 +14,7 @@
 @brief
 A null-terminated string containing the JasPer library version
 */
-#define	JAS_VERSION "4.1.2"
+#define	JAS_VERSION "4.2.2"
 
 /*!
 @brief
@@ -26,7 +26,7 @@ The JasPer library major version number.
 @brief
 The JasPer library minor version number.
 */
-#define JAS_VERSION_MINOR 1
+#define JAS_VERSION_MINOR 2
 
 /*!
 @brief
@@ -37,17 +37,17 @@ The JasPer library patch version number.
 /*
 The version of the C standard against which JasPer was built.
 */
-#define JAS_STDC_VERSION 201112L
+#define JAS_STDC_VERSION 199901L
 
 /* #undef JAS_ENABLE_32BIT */
 
 /* #undef JAS_HAVE_INT128_T */
 
 #define JAS_SIZEOF_INT 4
-#define JAS_SIZEOF_LONG 8
+#define JAS_SIZEOF_LONG 4
 #define JAS_SIZEOF_LLONG 8
-#define JAS_SIZEOF_SIZE_T 8
-#define JAS_SIZEOF_SSIZE_T 8
+#define JAS_SIZEOF_SIZE_T 4
+#define JAS_SIZEOF_SSIZE_T 4
 
 #define JAS_HAVE_FCNTL_H
 /* #undef JAS_HAVE_IO_H */
@@ -55,7 +55,7 @@ The version of the C standard against which JasPer was built.
 #define JAS_HAVE_SYS_TIME_H
 #define JAS_HAVE_SYS_TYPES_H
 /* #undef JAS_HAVE_SSIZE_T */
-#define JAS_HAVE_MAX_ALIGN_T
+/* #undef JAS_HAVE_MAX_ALIGN_T */
 
 #if 0
 /* #undef JAS_HAVE_UINTMAX_T */
@@ -76,7 +76,7 @@ The version of the C standard against which JasPer was built.
 #define JAS_INCLUDE_RAS_CODEC
 #define JAS_INCLUDE_JP2_CODEC
 #define JAS_INCLUDE_JPC_CODEC
-/* #undef JAS_INCLUDE_JPG_CODEC */
+#define JAS_INCLUDE_JPG_CODEC
 /* #undef JAS_INCLUDE_HEIC_CODEC */
 #define JAS_INCLUDE_PGX_CODEC
 #define JAS_INCLUDE_MIF_CODEC
